#! /bin/bash

INKSCAPE="/usr/bin/inkscape"
OPTIPNG="/usr/bin/optipng"

INDEX="assets.txt"

SRC_FILE="assets.svg"
ASSETS_DIR="assets"

for i in `cat $INDEX`
do
  if [ -f $ASSETS_DIR/$i.png ]; then
    echo $ASSETS_DIR/$i.png exists.
  else
    echo
    echo Rendering $ASSETS_DIR/$i.png
    $INKSCAPE --export-id=$i \
              --export-id-only \
              --export-png=$ASSETS_DIR/$i.png $SRC_FILE >/dev/null #\
    # && $OPTIPNG -o7 --quiet $ASSETS_DIR/$i.png 
  fi
  if [ -f $ASSETS_DIR/$i@2.png ]; then
    echo $ASSETS_DIR/$i@2.png exists.
  else
    echo
    echo Rendering $ASSETS_DIR/$i@2.png
    $INKSCAPE --export-id=$i \
              --export-dpi=180 \
              --export-id-only \
              --export-png=$ASSETS_DIR/$i@2.png $SRC_FILE >/dev/null #\
    # && $OPTIPNG -o7 --quiet $ASSETS_DIR/$i@2.png 
  fi
done

for i in "$ASSETS_DIR"/*-symbolic.svg; do
  name=$(basename "$i" .svg)
  png=$ASSETS_DIR/$name.symbolic.png

  if [ -f $png ]; then
    echo "$png exists."
  else
    echo
    echo Rendering "$png"
    $INKSCAPE --export-png="$png" \
              --export-background-opacity=0.0 "$i" >/dev/null #\
    # && $OPTIPNG -o7 --quiet "$png"
  fi
done
