// Ubuntu authd styles
// These styles support the Ubuntu authentication daemon (authd) patches
// applied distro-side in gnome-shell.
// See: https://salsa.debian.org/gnome-team/gnome-shell/-/tree/ubuntu/latest/debian/patches/ubuntu-authd

$_gdm_bg: $system_base_color;
$_gdm_fg: $system_fg_color;

// Auth menu button in login dialog
.login-dialog-button {
  &.login-dialog-auth-menu-button,
  &.web-login-intro-button {
    @extend .icon-button;
    @extend %system_button;

    padding: to_em(16px);
  }
}

.login-dialog-auth-menu-button-title {
  @include fontsize($base_font_size - 1);
  color: darken($_gdm_fg, 40%);
  font-weight: bold;
  padding-top: $base_padding;
  padding-bottom: $base_padding * 2;
  padding-left: $base_padding * 2;
  padding-right: $base_padding * 2;
}

.login-dialog-auth-menu-button-popup-menu-box {
  padding: $base_padding * 3;
}

.login-dialog-auth-menu-button-item {
  padding-left: $base_padding * 2;
  padding-right: $base_padding * 2;
}

.login-dialog-menu-button-box {
  spacing: $base_padding * 2;
  padding-left: $base_padding * 2;
  padding-right: $base_padding * 2;
  padding-bottom: $base_padding * 2;
}

// Web login
.web-login-dialog-content-overlay {
  background-color: transparentize($bg_color, 0.3);
  border-radius: $modal_radius;
  margin-bottom: 3em;
}

.web-login-spinner {
  color: $osd_fg_color;
  background-color: transparentize($osd_bg_color, 0.5);
  border: 5px transparent;
  border-radius: 50px;
}

.web-login-title-label {
  @include fontsize($base_font_size);
  color: if($variant == 'dark', darken($fg_color, 30%), lighten($fg_color, 20%));
}

.web-login-url-label {
  @include fontsize($base_font_size);
  @extend %monospace;
  color: $fg_color;
  text-align: center;
}

.web-login-code-title-label {
  @include fontsize($base_font_size);
  color: $fg_color;
}

.web-login-code-label {
  @include fontsize($base_font_size);
  color: $fg_color;
  font-weight: bold;
}

.web-login-prompt {
  padding-top: $base_padding;
  padding-bottom: $base_padding;
  padding-left: $base_padding * 4.5;
  padding-right: $base_padding * 4.5;
  spacing: 1.75em;
  border-radius: $base_border_radius * 2;
}

.web-login-intro-button-label {
  @include fontsize($base_font_size + 5);
  color: $fg_color;
  height: 3em;
  text-align: center;
  font-weight: bold;
}

.web-login-intro-button {
  @include fontsize($base_font_size);
  color: $fg_color;
  height: 3em;
  text-align: center;
  border-radius: $base_border_radius * 4;
}

// Login Failed banner
.auth-notification-banner {
  .message-header {
    width: 0px;
    height: 0px;

    .message-close-button {
      border: none;
      background-color: rgba(0, 0, 0, 0.0);
    }
  }
}

// Yaru change: increase min width of auth list items.
.login-dialog-auth-list-item {
  min-width: 300px;
}
